pub struct Size { /* private fields */ }Expand description
The Size flavor is a measurement flavor, which accumulates the number of bytes needed to
serialize the data.
use postcard::{serialize_with_flavor, ser_flavors};
let value = false;
let size = serialize_with_flavor(&value, ser_flavors::Size::default()).unwrap();
assert_eq!(size, 1);Trait Implementations
Sourceimpl Flavor for Size
impl Flavor for Size
Sourcetype Output = usize
type Output = usize
The
Output type is what this storage “resolves” to when the serialization is complete,
such as a slice or a Vec of some sort.Auto Trait Implementations
impl Freeze for Size
impl RefUnwindSafe for Size
impl Send for Size
impl Sync for Size
impl Unpin for Size
impl UnwindSafe for Size